@@ -1,9 +1,6 @@
-import logging
 from typing import Union
 
 from botocore.response import StreamingBody
-from datafet.http_return import http_404_json, http_500_json, json_error
-from fastapi.responses import JSONResponse
 from mypy_boto3_s3 import S3Client
 from mypy_boto3_s3.type_defs import GetObjectOutputTypeDef, PutObjectOutputTypeDef
 from mypy_boto3_secretsmanager import SecretsManagerClient
@@ -11,8 +8,8 @@ from mypy_boto3_secretsmanager.type_defs import GetSecretValueResponseTypeDef
 from mypy_boto3_sqs import SQSClient
 from mypy_boto3_sqs.type_defs import SendMessageResultTypeDef
 
-LOG = logging.getLogger(__name__)
-
+from ..custom_types import HttpError
+from ..http_return import http_error
 
 #
 # SecretsManager
@@ -38,16 +35,15 @@ e = [
 
 def get_secret_string(
     secrets_manager_client: SecretsManagerClient, secret_id: str
-) -> Union[str, JSONResponse]:
+) -> Union[str, HttpError]:
     try:
         secret_response: GetSecretValueResponseTypeDef = (
             secrets_manager_client.get_secret_value(SecretId=secret_id)
         )
-        secret_string_maybe = secret_response.get("SecretString", None)
-        if secret_string_maybe:
-            return secret_string_maybe
-        else:
-            return http_404_json(
+        return secret_response.get(
+            "SecretString",
+            default=http_error(
+                404,
                 "SecretsManager Error",
                 [
                     (
@@ -55,40 +51,40 @@ def get_secret_string(
                         f"The secret might be binary instead of string."
                     )
                 ],
-            )
+            ),
+        )
 
     except secrets_manager_client.exceptions.ClientError as ce:
         status_code = ce.response.get("ResponseMetadata", {}).get("HTTPStatusCode", 500)
         error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
-        return json_error(
-            status_code=status_code,
-            message="SecretsManager Error",
-            reasons=[
+        return http_error(
+            status_code,
+            "SecretsManager Error",
+            [
                 f"Could not get {secret_id} and a ClientError happened with status code: {status_code}",
                 error_code,
             ],
         )
 
     except Exception as ex:
-        return json_error(
-            status_code=500,
-            message="SecretsManager Error",
-            reasons=[f"Could not get {secret_id} and an exception happened: {ex}"],
+        return http_error(
+            500,
+            "SecretsManager Error",
+            [f"Could not get {secret_id} and an exception happened: {ex}"],
         )
 
 
 def get_secret_binary(
     secrets_manager_client: SecretsManagerClient, secret_id: str
-) -> Union[bytes, JSONResponse]:
+) -> Union[bytes, HttpError]:
     try:
         secret_response: GetSecretValueResponseTypeDef = (
             secrets_manager_client.get_secret_value(SecretId=secret_id)
         )
-        secret_bytes_maybe = secret_response.get("SecretBinary", None)
-        if secret_bytes_maybe:
-            return secret_bytes_maybe
-        else:
-            return http_404_json(
+        return secret_response.get(
+            "SecretBinary",
+            http_error(
+                404,
                 "SecretsManager Error",
                 [
                     (
@@ -96,14 +92,15 @@ def get_secret_binary(
                         f"The secret might be string instead of binary."
                     )
                 ],
-            )
+            ),
+        )
 
     except secrets_manager_client.exceptions.ClientError as ce:
         status_code = ce.response.get("ResponseMetadata", {}).get("HTTPStatusCode", 500)
         error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
-        return json_error(
-            status_code=status_code,
-            message="SecretsManager Error",
+        return http_error(
+            status_code,
+            "SecretsManager Error",
             reasons=[
                 f"Could not get {secret_id} and a ClientError happened with status code: {status_code}",
                 error_code,
@@ -111,10 +108,10 @@ def get_secret_binary(
         )
 
     except Exception as ex:
-        return json_error(
-            status_code=500,
-            message="SecretsManager Error",
-            reasons=[f"Could not get {secret_id} and an exception happened: {ex}"],
+        return http_error(
+            500,
+            "SecretsManager Error",
+            [f"Could not get {secret_id} and an exception happened: {ex}"],
         )
 
 
@@ -138,7 +135,7 @@ e = [
 
 def s3_get_object_stream(
     s3_client: S3Client, s3_bucket: str, s3_key: str
-) -> Union[StreamingBody, JSONResponse]:
+) -> Union[StreamingBody, HttpError]:
     try:
         s3_response: GetObjectOutputTypeDef = s3_client.get_object(
             Bucket=s3_bucket, Key=s3_key
@@ -146,8 +143,8 @@ def s3_get_object_stream(
         s3_stream_maybe = s3_response.get("Body")
 
         if s3_stream_maybe is None:
-            return http_500_json(
-                "S3 Error", [f"Could not get Body field from s3 response"]
+            return http_error(
+                500, "S3 Error", [f"Could not get Body field from s3 response"]
             )
 
         s3_stream_maybe.set_socket_timeout(3)
@@ -155,14 +152,14 @@ def s3_get_object_stream(
 
     except (s3_client.exceptions.NoSuchKey, s3_client.exceptions.NoSuchBucket) as ce:
         error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
-        return http_404_json(
-            "S3 Error", [f"Could not get s3://{s3_bucket}/{s3_key}", error_code]
+        return http_error(
+            404, "S3 Error", [f"Could not get s3://{s3_bucket}/{s3_key}", error_code]
         )
 
     except s3_client.exceptions.ClientError as ce:
         status_code = ce.response.get("ResponseMetadata", {}).get("HTTPStatusCode", 500)
         error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
-        return json_error(
+        return http_error(
             status_code=status_code,
             message="S3 Error",
             reasons=[
@@ -172,33 +169,28 @@ def s3_get_object_stream(
         )
 
     except Exception as ex:
-        LOG.error(f"Error: S3 Error. Reasons: {ex}")
-        return json_error(
-            status_code=500,
-            message="S3 Error",
-            reasons=[
-                f"Could not get s3://{s3_bucket}/{s3_key} and a Exception happened: {ex}"
-            ],
+        return http_error(
+            500,
+            "S3 Error",
+            [f"Could not get s3://{s3_bucket}/{s3_key} and a Exception happened: {ex}"],
         )
 
 
 def s3_get_object_bytes(
     s3_client: S3Client, s3_bucket: str, s3_key: str
-) -> Union[bytes, JSONResponse]:
+) -> Union[bytes, HttpError]:
     try:
 
         s3_stream_maybe = s3_get_object_stream(
             s3_client=s3_client, s3_bucket=s3_bucket, s3_key=s3_key
         )
-
-        if isinstance(s3_stream_maybe, StreamingBody):
-            return s3_stream_maybe.read()
-        else:
+        if isinstance(s3_stream_maybe, HttpError):
             return s3_stream_maybe
 
+        return s3_stream_maybe.read()
+
     except Exception as ex:
-        LOG.error(f"Error: Unexpected error. Reasons: {ex}")
-        return json_error(
+        return http_error(
             status_code=500,
             message="S3 Error",
             reasons=[
@@ -209,7 +201,7 @@ def s3_get_object_bytes(
 
 def s3_put_object_bytes(
     s3_client: S3Client, s3_bucket: str, s3_key: str, s3_body_bytes: bytes
-) -> Union[PutObjectOutputTypeDef, JSONResponse]:
+) -> Union[PutObjectOutputTypeDef, HttpError]:
     try:
         s3_response: PutObjectOutputTypeDef = s3_client.put_object(
             Bucket=s3_bucket, Key=s3_key, Body=s3_body_bytes
@@ -218,12 +210,12 @@ def s3_put_object_bytes(
         return s3_response
 
     except s3_client.exceptions.NoSuchBucket:
-        return http_404_json("S3 Error", [f"Could not find bucket: {s3_bucket}"])
+        return http_error(404, "S3 Error", [f"Could not find bucket: {s3_bucket}"])
 
     except s3_client.exceptions.ClientError as ce:
         status_code = ce.response.get("ResponseMetadata", {}).get("HTTPStatusCode", 500)
         error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
-        return json_error(
+        return http_error(
             status_code=status_code,
             message="S3 Error",
             reasons=[
@@ -233,7 +225,7 @@ def s3_put_object_bytes(
         )
 
     except Exception as ex:
-        return json_error(
+        return http_error(
             status_code=500,
             message="S3 Error",
             reasons=[
@@ -265,7 +257,7 @@ e = [
 
 def send_sqs_message_fifo(
     sqs_client: SQSClient, queue_url: str, message_body: str, message_group_id: str
-) -> Union[SendMessageResultTypeDef, JSONResponse]:
+) -> Union[SendMessageResultTypeDef, HttpError]:
     try:
         return sqs_client.send_message(
             QueueUrl=queue_url,
@@ -275,19 +267,20 @@ def send_sqs_message_fifo(
     except sqs_client.exceptions.ClientError as ce:
         status_code = ce.response.get("ResponseMetadata", {}).get("HTTPStatusCode", 500)
         error_code = ce.response.get("Error", {}).get("Code", "ErrorCodeMissing")
-        return json_error(
+        return http_error(
             status_code,
             "SQS Error",
             [f"Could not send message to queue: {queue_url}", error_code],
         )
     except Exception as ex:
-        message, reasons = "SQS Error", [
-            (
+        return http_error(
+            500,
+            message="SQS Error",
+            reasons=(
                 f"Could not send SQS message {message_body} to queue_url: {queue_url}"
                 f"message_group_id: {message_group_id} becasue of {ex}"
-            )
-        ]
-        return http_500_json(message=message, reasons=reasons)
+            ),
+        )
 
 
 # import boto3
