@@ -1,10 +1,10 @@
 from typing import Any, List
 
-from datafet.custom_types import CustomError
-from datafet.custom_types.custom_types import HttpError
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import JSONResponse
 
+from ..custom_types import CustomError, HttpError
+
 #
 # PYDANTIC ERROR
 #
@@ -37,6 +37,12 @@ def http_error(status_code: int, message: str, reasons: List[str]) -> HttpError:
     return HttpError(status_code, CustomError(message, reasons))
 
 
+def http_error_to_json_response(http_error: HttpError) -> JSONResponse:
+    return JSONResponse(
+        status_code=http_error.status_code, content=jsonable_encoder(http_error.error)
+    )
+
+
 #
 # 2xx
 #
